Package: svglite
Version: 2.0.0
Title: An 'SVG' Graphics Device
Description: A graphics device for R that produces 'Scalable Vector Graphics'.
  'svglite' is a fork of the older 'RSvgDevice' package.
Authors@R: c(
  person("Hadley", "Wickham", , "hadley@rstudio.com", "aut"),
  person("Lionel", "Henry", , "lionel@rstudio.com", c("aut")),
  person("Thomas Lin", "Pedersen", , "thomas.pedersen@rstudio.com", c("cre", "aut"), comment = c(ORCID = "0000-0002-5147-4711")),
  person("T Jake", "Luciani", , "jake@apache.org", "aut"),
  person("Matthieu", "Decorde", , "matthieu.decorde@ens-lyon.fr", "aut"),
  person("Vaudor", "Lise", , "lise.vaudor@ens-lyon.fr", "aut"),
  person("Tony", "Plate", role = "ctb", comment = "Early line dashing code"),
  person("David", "Gohel", role = "ctb", comment = "Line dashing code and early raster code"),
  person("Yixuan", "Qiu", role = "ctb", comment = "Improved styles; polypath implementation"),
  person("Håkon", "Malmedal", role = "ctb", comment = "Opacity code"),
  person("RStudio", role = "cph")
  )
Encoding: UTF-8
SystemRequirements: C++11, libpng
Depends: R (>= 3.0.0)
Imports: systemfonts (>= 1.0.0)
LinkingTo: cpp11, systemfonts
Suggests: htmltools, testthat, xml2 (>= 1.0.0), covr, fontquiver (>=
        0.2.0), knitr, rmarkdown
License: GPL (>= 2)
URL: https://svglite.r-lib.org, https://github.com/r-lib/svglite
BugReports: https://github.com/r-lib/svglite/issues
RoxygenNote: 7.1.1
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2021-02-18 13:52:01 UTC; thomas
Author: Hadley Wickham [aut],
  Lionel Henry [aut],
  Thomas Lin Pedersen [cre, aut]
    (<https://orcid.org/0000-0002-5147-4711>),
  T Jake Luciani [aut],
  Matthieu Decorde [aut],
  Vaudor Lise [aut],
  Tony Plate [ctb] (Early line dashing code),
  David Gohel [ctb] (Line dashing code and early raster code),
  Yixuan Qiu [ctb] (Improved styles; polypath implementation),
  Håkon Malmedal [ctb] (Opacity code),
  RStudio [cph]
Maintainer: Thomas Lin Pedersen <thomas.pedersen@rstudio.com>
Repository: CRAN
Date/Publication: 2021-02-20 01:30:06 UTC
Built: R 4.0.3; x86_64-w64-mingw32; 2021-02-20 03:42:45 UTC; windows
Archs: x64
