# Generated by roxygen2: do not edit by hand

S3method(print,svg)
export(editSVG)
export(htmlSVG)
export(stringSVG)
export(svglite)
export(svgstring)
export(xmlSVG)
importFrom(Rcpp,sourceCpp)
importFrom(gdtools,raster_view)
useDynLib(svglite)
